summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoDocument.cpp')
-rw-r--r--lib/kofficecore/KoDocument.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficecore/KoDocument.cpp b/lib/kofficecore/KoDocument.cpp
index fd790991..f881293a 100644
--- a/lib/kofficecore/KoDocument.cpp
+++ b/lib/kofficecore/KoDocument.cpp
@@ -1222,7 +1222,7 @@ TQPixmap KoDocument::generatePreview( const TQSize& size )
docHeight = m_pageLayout.ptHeight / 72 * KoGlobal::dpiY();
} else {
// If we don't have a page tqlayout, just draw the top left hand corner
docWidth = 500.0;
docHeight = 500.0;
}
@@ -2656,7 +2656,7 @@ bool KoDocument::showEmbedInitDialog(TQWidget* parent)
{
KDialogBase dlg(parent, "EmbedInitDialog", true, i18n("Embedding Object"), 0, KDialogBase::NoDefault);
KoOpenPane* pane = createOpenPane(&dlg, instance(), templateType());
- pane->tqlayout()->setMargin(0);
+ pane->layout()->setMargin(0);
dlg.setMainWidget(pane);
dlg.setInitialSize(dlg.configDialogSize("EmbedInitDialog"));
connect(this, TQT_SIGNAL(closeEmbedInitDialog()), &dlg, TQT_SLOT(slotOk()));
@@ -1222,7 +1222,7 @@ TQPixmap KoDocument::generatePreview( const TQSize& size )
docHeight = m_pageLayout.ptHeight / 72 * KoGlobal::dpiY();
} else {
- // If we don't have a page tqlayout, just draw the top left hand corner
+ // If we don't have a page layout, just draw the top left hand corner
docWidth = 500.0;
docHeight = 500.0;